function struct1 = mergeNexFiles(struct1,struct2)
% mergeNexFiles is a helper function to merge two Neuroexplorer file Structures
%
% Usage:
%  >> struct1 = mergeNexFiles(struct1,struct2)
%
% Inputs:
%   struct1   - STRUCT of Nex Data;
%   struct2   - STRUCT of Nex Data;
%
% Outputs:
%   struct1   - Appended struct1.
%
% See also: 
%
% Copyright (C) 2010 by David Devilbiss <ddevilbiss@wisc.edu>
%  v. 1.0 DMD 10Oct2010
%


FileGap = 0;
struct1varCount = 0;

%initially check to see if .tEnd and Stop are the same number
File1tEnd = ceil(struct1.tend);
File1EventStruct = [struct1.events{:}];
File1EventNames = {File1EventStruct.name};
clear File1EventStruct;
File1Stop = ceil(struct1.events{find(strcmp(File1EventNames,'Stop'))}.timestamps(end));
if File1tEnd ~= File1Stop && File1Stop < File1tEnd
    File1tEnd = File1Stop;
elseif File1Stop > File1tEnd
    disp('WARNING >> mergeNexFiles: File "Stop" > file end');
end
%update tend
struct1.tend = File1tEnd + FileGap + struct2.tend;


% check for correct # and type of variables (most of the time they won't contain the same variables [one has more blocks])
%this may not be needed
nFieldCounter = 0;
File1Fieldnames = fieldnames(struct1);
File2Fieldnames = fieldnames(struct2);
for curField = 1:length(File1Fieldnames)
    if any(strcmp(File1Fieldnames{curField},File2Fieldnames))
        nFieldCounter = nFieldCounter +1;
    end
end
if length(File1Fieldnames) ~= length(File2Fieldnames) || ...
        nFieldCounter ~= length(File1Fieldnames) || ...
        nFieldCounter ~= length(File2Fieldnames) || ...
        struct1.nvar ~= struct2.nvar
    disp('WARNING >> mergeNexFiles: Files do not contain the same variables')
    fixVars = true;
else
    fixVars = false;
end

%move struct 2 into struct 1
for curField = 1:length(File2Fieldnames)
    File1Struct = []; File1FieldNames = [];
    %Things containing variables are in cell arrays (Here we are going
    %through struct 2 and adding them to struct 1)
    if iscell(struct2.(File2Fieldnames{curField}))
        %make sure file1 fieldname is file2 fieldname and unique
        if nnz(strcmp(File2Fieldnames{curField},File1Fieldnames)) == 1
            %get struct 1 .names
            File1FieldStruct = [struct1.(File2Fieldnames{curField}){:}];
            File1VarNames = {File1FieldStruct.name};
            clear File1FieldStruct;
            %loop through each cell's data of struct 2
            for curData = 1:length(struct2.(File2Fieldnames{curField}))
                %data is going to be designated as a type
                % either haveing intStarts/intEnds, timestamps
                type = struct2.(File2Fieldnames{curField}){curData}.type;
                %find struct 1 index (varIDX is an index into struct1 variables)
                varIDX = find(strcmp(File1VarNames,struct2.(File2Fieldnames{curField}){curData}.name));

                if ~isempty(varIDX)
                    switch type
                        case {0,1}  %neurons,events
                            %Update variables
                            struct1.(File2Fieldnames{curField}){varIDX}.timestamps = ...
                                [struct1.(File2Fieldnames{curField}){varIDX}.timestamps ; ...
                                struct2.(File2Fieldnames{curField}){curData}.timestamps + FileGap + File1tEnd];

                            struct1.(File2Fieldnames{curField}){varIDX}.nEvents = ...
                                struct1.(File2Fieldnames{curField}){varIDX}.nEvents + struct2.(File2Fieldnames{curField}){curData}.nEvents;

                            struct1.(File2Fieldnames{curField}){varIDX}.FilePosDataOffset = -1; %reset for writing later

                        case 2 %intervals
                            if strcmpi(struct1.(File2Fieldnames{curField}){varIDX}.name,'allfile')
                                struct1.(File2Fieldnames{curField}){varIDX}.intEnds = ...
                                    struct2.(File2Fieldnames{curField}){curData}.intEnds;
                                struct1.(File2Fieldnames{curField}){varIDX}.FilePosDataOffset = -1; %reset for writing later
                            else
                                struct1.(File2Fieldnames{curField}){varIDX}.intStarts = ...
                                    [struct1.(File2Fieldnames{curField}){varIDX}.intStarts ; ...
                                    struct2.(File2Fieldnames{curField}){curData}.intStarts + FileGap + File1tEnd];

                                struct1.(File2Fieldnames{curField}){varIDX}.intEnds = ...
                                    [struct1.(File2Fieldnames{curField}){varIDX}.intEnds ; ...
                                    struct2.(File2Fieldnames{curField}){curData}.intEnds + FileGap + File1tEnd];

                                struct1.(File2Fieldnames{curField}){varIDX}.nEvents = ...
                                    struct1.(File2Fieldnames{curField}){varIDX}.nEvents + struct2.(File2Fieldnames{curField}){curData}.nEvents;

                                struct1.(File2Fieldnames{curField}){varIDX}.FilePosDataOffset = -1; %reset for writing later
                            end

                        case 3 %waves
                            struct1.(File2Fieldnames{curField}){varIDX}.timestamps = ...
                                [struct1.(File2Fieldnames{curField}){varIDX}.timestamps ; ...
                                struct2.(File2Fieldnames{curField}){curData}.timestamps + FileGap + File1tEnd];

                            struct1.(File2Fieldnames{curField}){varIDX}.waveforms = ...
                                [struct1.(File2Fieldnames{curField}){varIDX}.waveforms , ...
                                struct2.(File2Fieldnames{curField}){curData}.waveforms];

                            struct1.(File2Fieldnames{curField}){varIDX}.nEvents = ...
                                struct1.(File2Fieldnames{curField}){varIDX}.nEvents + struct2.(File2Fieldnames{curField}){curData}.nEvents;

                            struct1.(File2Fieldnames{curField}){varIDX}.FilePosDataOffset = -1; %reset for writing later

                        case 5 %continuous
                            struct1.(File2Fieldnames{curField}){varIDX}.timestamps = ...
                                [struct1.(File2Fieldnames{curField}){varIDX}.timestamps ; ...
                                struct2.(File2Fieldnames{curField}){curData}.timestamps + FileGap + File1tEnd];

                            struct1.(File2Fieldnames{curField}){varIDX}.fragmentStarts = ...
                                struct1.(File2Fieldnames{curField}){varIDX}.fragmentStarts + struct2.(File2Fieldnames{curField}){curData}.fragmentStarts;

                            %out of memory error
                            try
                                struct1.(File2Fieldnames{curField}){varIDX}.data = ...
                                    [struct1.(File2Fieldnames{curField}){varIDX}.data ; ...
                                    struct2.(File2Fieldnames{curField}){curData}.data];
                            catch
                                %there is a faster way of doing this but I am feeling lazy today
                                hw2 = waitbar(0,'copying continuous data ...');
                                for curdatapt = 1:100000:length(struct2.(File2Fieldnames{curField}){curData}.data)
                                    waitbar(curdatapt/length(struct2.(File2Fieldnames{curField}){curData}.data),hw2);
                                    struct1.(File2Fieldnames{curField}){varIDX}.data(end +1:end +100001) = struct2.(File2Fieldnames{curField}){curData}.data(curdatapt:curdatapt+100000);
                                end
                                close(hw);
                            end

                            struct1.(File2Fieldnames{curField}){varIDX}.nEvents = ...
                                struct1.(File2Fieldnames{curField}){varIDX}.nEvents + struct2.(File2Fieldnames{curField}){curData}.nEvents;

                            struct1.(File2Fieldnames{curField}){varIDX}.FilePosDataOffset = -1; %reset for writing later

                        otherwise
                            disp(['WARNING >> mergeNexFiles: Data Type: ',num2str(type),': ',File2Fieldnames{curField},' not specified']);
                    end %of switch
                    %struct2.(File2Fieldnames{curField}){curData} = []; %clear the cell to grab memory
                else
                    disp(['WARNING >> mergeNexFiles: Data Type: ',num2str(type),': ',struct2.(File2Fieldnames{curField}){curData}.name,' does not exist in 1st struct']);
                    % copy variable over
                    struct1.(File2Fieldnames{curField}){end +1} = struct2.(File2Fieldnames{curField}){curData};
                end
            end %of struct 2 node loop
            %tally up variables so far in Struct1
            File1FieldStruct = [struct1.(File2Fieldnames{curField}){:}];
            struct1varCount = struct1varCount +length({File1FieldStruct.name});
            
        else
            disp(['WARNING >> mergeNexFiles: Data Type: ',File2Fieldnames{curField},' does not exist in 1st struct']);
        end
    end
end

%Before you are finished update nvar and comment
struct1.comment = [struct1.comment,' +++ ',struct2.comment];
struct1.nvar = struct1varCount;



